package kr.xit.core.biz.batch.mapper;

import java.util.List;
import java.util.Optional;
import kr.xit.core.biz.batch.model.BatchCmmDTO.BatchLock;
import org.egovframe.rte.psl.dataaccess.mapper.Mapper;

/**
 * <pre>
 * description :
 *
 * packageName : kr.xit.core.biz.batch.mapper
 * fileName    : IBatchCmmMapper
 * author      : limju
 * date        : 2023-05-16
 * ======================================================================
 * 변경일         변경자        변경 내용
 * ----------------------------------------------------------------------
 * 2023-05-16    limju       최초 생성
 * 2023-10-19    limju       배치관리 업무 추가
 *
 * </pre>
 */
@Mapper
public interface IBatchCmmMapper {
    Optional<BatchLock> selectBatchLockByInstanceId(final String instanceId);
    int insertBatchLock(final BatchLock dto);
    int updateBatchLock(final BatchLock dto);

    int insertBatchLog(final BatchLock dto);
    int updateBatchLog(final BatchLock dto);

    List<BatchLock> selectBatchLocks();
    Optional<BatchLock> selectBatchLock(final String instanceId);
}
